# 2023-09-15 - Stakeless Gauge Checkpointer V2

Deployment of the `StakelessGaugeCheckpointer` contract. It automates the process of performing checkpoints to stakeless root gauges.
Replaces the [`StakelessGaugeCheckpointer V1`](../deprecated/20230731-stakeless-gauge-checkpointer/), adding compatibility for paid gauges outside the Arbitrum network (e.g. Avalanche) in a more generic and future-proof way.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`StakelessGaugeCheckpointer` artifact](./artifact/StakelessGaugeCheckpointer.json)
